| xkcd | R Documentation |
A data frame mapping hex codes for 949 colors to their consensus names in the XKCD color survey.
data(xkcd)
A data frame with two columns and 949 rows.
This data set contains the names and hex codes for 949 color names identified as consistent in the Color Survey run by Randall Munroe at XKCD. During the online survey, more than five million color swatches were named across 222,500 user sessions. In the blog post describing the results, Munroe describes the method he used to come up with a list of "consensus" color names. He also says the text file should contain 954 color names, but the downloaded text file only contained 949. Data were reformatted to be usable as a data frame in R, with underscores inserted in place of spaces in multi-word color names.
Our main source was the text file linked to from https://blog.xkcd.com/2010/05/03/color-survey-results/.
xkcdNames
data(xkcd)
head(xkcd)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.